CIBSE Guide E
=============

*Chartered Institution of Building Services Engineers (CIBSE) (2019) CIBSE Guide E: Fire safety engineering. London: CIBSE.*

CIBSE Guide E provides guidance on fire safety engineering for buildings.

.. automodule:: ofire.cibse_guide_e
   :members:
   :undoc-members:
   :show-inheritance:

Chapter 6 - Fire and Smoke
--------------------------

.. automodule:: ofire.cibse_guide_e.chapter_6
   :members:
   :undoc-members:
   :show-inheritance:

Chapter 6 Equations
~~~~~~~~~~~~~~~~~~~

Equation 6.7 - Heat Release Rate at Flashover
""""""""""""""""""""""""""""""""""""""""""""""

.. automodule:: ofire.cibse_guide_e.chapter_6.equation_6_7
   :members:
   :undoc-members:
   :show-inheritance:

Equation 6.55 - Mean Flame Height
""""""""""""""""""""""""""""""""""

.. automodule:: ofire.cibse_guide_e.chapter_6.equation_6_55
   :members:
   :undoc-members:
   :show-inheritance:

Equation 6.57 - Height of Flame Above Opening
""""""""""""""""""""""""""""""""""""""""""""""

.. automodule:: ofire.cibse_guide_e.chapter_6.equation_6_57
   :members:
   :undoc-members:
   :show-inheritance:

Equation 6.58 - Ventilation-Controlled Rate of Burning
"""""""""""""""""""""""""""""""""""""""""""""""""""""""

.. automodule:: ofire.cibse_guide_e.chapter_6.equation_6_58
   :members:
   :undoc-members:
   :show-inheritance:

Chapter 6 Appendix
~~~~~~~~~~~~~~~~~~

.. automodule:: ofire.cibse_guide_e.chapter_6.appendix
   :members:
   :undoc-members:
   :show-inheritance:

Chapter 7 - Means of Escape
---------------------------

.. automodule:: ofire.cibse_guide_e.chapter_7
   :members:
   :undoc-members:
   :show-inheritance:

Chapter 7 Equations
~~~~~~~~~~~~~~~~~~~

Equation 7.2 - Stair Capacity
""""""""""""""""""""""""""""""

.. automodule:: ofire.cibse_guide_e.chapter_7.equation_7_2
   :members:
   :undoc-members:
   :show-inheritance:

Equation 7.3 - Required Width of Stair
"""""""""""""""""""""""""""""""""""""""

.. automodule:: ofire.cibse_guide_e.chapter_7.equation_7_3
   :members:
   :undoc-members:
   :show-inheritance:

Equation 7.6 - Maximum Flow Rate of Persons
""""""""""""""""""""""""""""""""""""""""""""

.. automodule:: ofire.cibse_guide_e.chapter_7.equation_7_6
   :members:
   :undoc-members:
   :show-inheritance:

Equation 7.7 - Maximum People in Stair
"""""""""""""""""""""""""""""""""""""""

.. automodule:: ofire.cibse_guide_e.chapter_7.equation_7_7
   :members:
   :undoc-members:
   :show-inheritance:

Equation 7.8 - Exit Capacity of Stair
""""""""""""""""""""""""""""""""""""""

.. automodule:: ofire.cibse_guide_e.chapter_7.equation_7_8
   :members:
   :undoc-members:
   :show-inheritance:

Equation 7.9 - Acceptance Capacity of Stair
""""""""""""""""""""""""""""""""""""""""""""

.. automodule:: ofire.cibse_guide_e.chapter_7.equation_7_9
   :members:
   :undoc-members:
   :show-inheritance:

Chapter 10 - Smoke Control
--------------------------

.. automodule:: ofire.cibse_guide_e.chapter_10
   :members:
   :undoc-members:
   :show-inheritance:

Chapter 10 Equations
~~~~~~~~~~~~~~~~~~~~

Equation 10.1 - Maximum Volumetric Flow Rate
"""""""""""""""""""""""""""""""""""""""""""""

.. automodule:: ofire.cibse_guide_e.chapter_10.equation_10_1
   :members:
   :undoc-members:
   :show-inheritance:

Equation 10.2 - Minimum Separation Distance Between Vents
""""""""""""""""""""""""""""""""""""""""""""""""""""""""""

.. automodule:: ofire.cibse_guide_e.chapter_10.equation_10_2
   :members:
   :undoc-members:
   :show-inheritance:

Equation 10.3 - Volumetric Flow Rate
"""""""""""""""""""""""""""""""""""""

.. automodule:: ofire.cibse_guide_e.chapter_10.equation_10_3
   :members:
   :undoc-members:
   :show-inheritance:

Equation 10.4 - Time to Burning Skin
"""""""""""""""""""""""""""""""""""""

.. automodule:: ofire.cibse_guide_e.chapter_10.equation_10_4
   :members:
   :undoc-members:
   :show-inheritance:

Equation 10.7 - Visibility
"""""""""""""""""""""""""""

.. automodule:: ofire.cibse_guide_e.chapter_10.equation_10_7
   :members:
   :undoc-members:
   :show-inheritance:

Equation 10.8 - Fractional Effective Dose
""""""""""""""""""""""""""""""""""""""""""

.. automodule:: ofire.cibse_guide_e.chapter_10.equation_10_8
   :members:
   :undoc-members:
   :show-inheritance:

Equation 10.10 - Limiting Average Air Velocity for Opposed Air Flow Ventilation
""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""

.. automodule:: ofire.cibse_guide_e.chapter_10.equation_10_10
   :members:
   :undoc-members:
   :show-inheritance:

Equation 10.11 - Limiting Average Air Velocity to Prevent Smoke Spread from Large Spaces
"""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""

.. automodule:: ofire.cibse_guide_e.chapter_10.equation_10_11
   :members:
   :undoc-members:
   :show-inheritance:

Equation 10.12 - Limiting Average Inlet Air Velocity to Prevent Smoke Spread Upstream
""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""

.. automodule:: ofire.cibse_guide_e.chapter_10.equation_10_12
   :members:
   :undoc-members:
   :show-inheritance: